diff --git a/app/Abstracts/View/Components/TransferShow.php b/app/Abstracts/View/Components/TransferShow.php
index f6045640a..2244dd80f 100644
--- a/app/Abstracts/View/Components/TransferShow.php
+++ b/app/Abstracts/View/Components/TransferShow.php
@@ -392,7 +392,7 @@ abstract class TransferShow extends Component
$this->hideDetailDescription = $hideDetailDescription;
$this->hideDetailAmount = $hideDetailAmount;
- // Releated Information Text
+ // Related Information Text
$this->textDetailTitle = $this->getTextDetailTitle($textDetailTitle);
$this->textDetailDate = $this->getTextDetailDate($textDetailDate);
$this->textDetailPaymentMethod = $this->getTextDetailPaymentMethod($textDetailPaymentMethod);
diff --git a/app/Abstracts/View/Components/TransferTemplate.php b/app/Abstracts/View/Components/TransferTemplate.php
index b1b11725b..6f54f4360 100644
--- a/app/Abstracts/View/Components/TransferTemplate.php
+++ b/app/Abstracts/View/Components/TransferTemplate.php
@@ -177,7 +177,7 @@ abstract class TransferTemplate extends Component
$this->hideDetailDescription = $hideDetailDescription;
$this->hideDetailAmount = $hideDetailAmount;
- // Releated Information Text
+ // Related Information Text
$this->textDetailTitle = $this->getTextDetailTitle($textDetailTitle);
$this->textDetailDate = $this->getTextDetailDate($textDetailDate);
$this->textDetailPaymentMethod = $this->getTextDetailPaymentMethod($textDetailPaymentMethod);
diff --git a/resources/lang/en-GB/payments.php b/resources/lang/en-GB/payments.php
index 6d0da5bea..159070ca6 100644
--- a/resources/lang/en-GB/payments.php
+++ b/resources/lang/en-GB/payments.php
@@ -4,7 +4,7 @@ return [
'payment_made' => 'Payment Made',
'paid_to' => 'Paid To',
- 'related_bill' => 'Releated Bill',
+ 'related_bill' => 'Related Bill',
'create_payment' => 'Create Payment',
];
diff --git a/resources/lang/en-GB/revenues.php b/resources/lang/en-GB/revenues.php
index 550d65b45..36c0627b3 100644
--- a/resources/lang/en-GB/revenues.php
+++ b/resources/lang/en-GB/revenues.php
@@ -4,7 +4,7 @@ return [
'revenue_received' => 'Revenue Received',
'paid_by' => 'Paid By',
- 'related_invoice' => 'Releated Invoice',
+ 'related_invoice' => 'Related Invoice',
'create_revenue' => 'Create Revenue',
];
diff --git a/resources/views/components/transactions/show/content.blade.php b/resources/views/components/transactions/show/content.blade.php
index 22b2fb4f4..e1d334ac9 100644
--- a/resources/views/components/transactions/show/content.blade.php
+++ b/resources/views/components/transactions/show/content.blade.php
@@ -73,19 +73,19 @@
hide-contact-phone="{{ $hideContactPhone }}"
hide-contact-email="{{ $hideContactEmail }}"
- hide-releated="{{ $hideReletad }}"
- hide-releated-document-number="{{ $hideReletadDocumentNumber }}"
- hide-releated-contact="{{ $hideReletadContact }}"
- hide-releated-document-date="{{ $hideReletadDocumentDate }}"
- hide-releated-document-amount="{{ $hideReletadDocumentAmount }}"
- hide-releated-amount="{{ $hideReletadAmount }}"
+ hide-related="{{ $hideRelated }}"
+ hide-related-document-number="{{ $hideRelatedDocumentNumber }}"
+ hide-related-contact="{{ $hideRelatedContact }}"
+ hide-related-document-date="{{ $hideRelatedDocumentDate }}"
+ hide-related-document-amount="{{ $hideRelatedDocumentAmount }}"
+ hide-related-amount="{{ $hideRelatedAmount }}"
- text-releated-transaction="{{ $textReleatedTransansaction }}"
- text-releated-document-number="{{ $textReleatedDocumentNumber }}"
- text-releated-contact="{{ $textReleatedContact }}"
- text-releated-document-date="{{ $textReleatedDocumentDate }}"
- text-releated-document-amount="{{ $textReleatedDocumentAmount }}"
- text-releated-amount="{{ $textReleatedAmount }}"
+ text-related-transaction="{{ $textRelatedTransansaction }}"
+ text-related-document-number="{{ $textRelatedDocumentNumber }}"
+ text-related-contact="{{ $textRelatedContact }}"
+ text-related-document-date="{{ $textRelatedDocumentDate }}"
+ text-related-document-amount="{{ $textRelatedDocumentAmount }}"
+ text-related-amount="{{ $textRelatedAmount }}"
route-document-show="{{ $routeDocumentShow }}"
/>
diff --git a/resources/views/components/transactions/show/transaction.blade.php b/resources/views/components/transactions/show/transaction.blade.php
index fd26fbc3e..ad89f1798 100644
--- a/resources/views/components/transactions/show/transaction.blade.php
+++ b/resources/views/components/transactions/show/transaction.blade.php
@@ -49,19 +49,19 @@
hide-contact-phone="{{ $hideContactPhone }}"
hide-contact-email="{{ $hideContactEmail }}"
- hide-releated="{{ $hideReletad }}"
- hide-releated-document-number="{{ $hideReletadDocumentNumber }}"
- hide-releated-contact="{{ $hideReletadContact }}"
- hide-releated-document-date="{{ $hideReletadDocumentDate }}"
- hide-releated-document-amount="{{ $hideReletadDocumentAmount }}"
- hide-releated-amount="{{ $hideReletadAmount }}"
+ hide-related="{{ $hideRelated }}"
+ hide-related-document-number="{{ $hideRelatedDocumentNumber }}"
+ hide-related-contact="{{ $hideRelatedContact }}"
+ hide-related-document-date="{{ $hideRelatedDocumentDate }}"
+ hide-related-document-amount="{{ $hideRelatedDocumentAmount }}"
+ hide-related-amount="{{ $hideRelatedAmount }}"
- text-releated-transaction="{{ $textReleatedTransansaction }}"
- text-releated-document-number="{{ $textReleatedDocumentNumber }}"
- text-releated-contact="{{ $textReleatedContact }}"
- text-releated-document-date="{{ $textReleatedDocumentDate }}"
- text-releated-document-amount="{{ $textReleatedDocumentAmount }}"
- text-releated-amount="{{ $textReleatedAmount }}"
+ text-related-transaction="{{ $textRelatedTransansaction }}"
+ text-related-document-number="{{ $textRelatedDocumentNumber }}"
+ text-related-contact="{{ $textRelatedContact }}"
+ text-related-document-date="{{ $textRelatedDocumentDate }}"
+ text-related-document-amount="{{ $textRelatedDocumentAmount }}"
+ text-related-amount="{{ $textRelatedAmount }}"
route-document-show="{{ $routeDocumentShow }}"
/>
diff --git a/resources/views/components/transactions/template/default.blade.php b/resources/views/components/transactions/template/default.blade.php
index dada35746..c961193b4 100644
--- a/resources/views/components/transactions/template/default.blade.php
+++ b/resources/views/components/transactions/template/default.blade.php
@@ -258,7 +258,7 @@
-@if (!$hideReletad)
+@if (!$hideRelated)
@if ($transaction->document)
@@ -269,7 +269,7 @@
- {{ trans($textReleatedTransansaction) }}
+ {{ trans($textRelatedTransansaction) }}
|
@@ -277,33 +277,33 @@
- @if (!$hideReletadDocumentNumber)
+ @if (!$hideRelatedDocumentNumber)
- {{ trans_choice($textReleatedDocumentNumber, 1) }}
+ {{ trans_choice($textRelatedDocumentNumber, 1) }}
|
@endif
- @if (!$hideReletadContact)
+ @if (!$hideRelatedContact)
- {{ trans_choice($textReleatedContact, 1) }}
+ {{ trans_choice($textRelatedContact, 1) }}
|
@endif
- @if (!$hideReletadDocumentDate)
+ @if (!$hideRelatedDocumentDate)
- {{ trans($textReleatedDocumentDate) }}
+ {{ trans($textRelatedDocumentDate) }}
|
@endif
- @if (!$hideReletadDocumentAmount)
+ @if (!$hideRelatedDocumentAmount)
- {{ trans($textReleatedDocumentAmount) }}
+ {{ trans($textRelatedDocumentAmount) }}
|
@endif
- @if (!$hideReletadAmount)
+ @if (!$hideRelatedAmount)
- {{ trans($textReleatedAmount) }}
+ {{ trans($textRelatedAmount) }}
|
@endif
@@ -311,7 +311,7 @@
- @if (!$hideReletadDocumentNumber)
+ @if (!$hideRelatedDocumentNumber)
{{ $transaction->document->document_number }}
@@ -319,25 +319,25 @@
|
@endif
- @if (!$hideReletadContact)
+ @if (!$hideRelatedContact)
{{ $transaction->document->contact_name }}
|
@endif
- @if (!$hideReletadDocumentDate)
+ @if (!$hideRelatedDocumentDate)
@date($transaction->document->due_at)
|
@endif
- @if (!$hideReletadDocumentAmount)
+ @if (!$hideRelatedDocumentAmount)
@money($transaction->document->amount, $transaction->document->currency_code, true)
|
@endif
- @if (!$hideReletadAmount)
+ @if (!$hideRelatedAmount)
@money($transaction->amount, $transaction->currency_code, true)
|
diff --git a/app/Abstracts/View/Components/TransactionShow.php b/app/Abstracts/View/Components/TransactionShow.php
index 28ca2b6ce..277333cfe 100644
--- a/app/Abstracts/View/Components/TransactionShow.php
+++ b/app/Abstracts/View/Components/TransactionShow.php
@@ -257,40 +257,40 @@ abstract class TransactionShow extends Base
public $hideContactEmail;
/** @var bool */
- public $hideReletad;
+ public $hideRelated;
/** @var bool */
- public $hideReletadDocumentNumber;
+ public $hideRelatedDocumentNumber;
/** @var bool */
- public $hideReletadContact;
+ public $hideRelatedContact;
/** @var bool */
- public $hideReletadDocumentDate;
+ public $hideRelatedDocumentDate;
/** @var bool */
- public $hideReletadDocumentAmount;
+ public $hideRelatedDocumentAmount;
/** @var bool */
- public $hideReletadAmount;
+ public $hideRelatedAmount;
/** @var string */
- public $textReleatedTransansaction;
+ public $textRelatedTransansaction;
/** @var string */
- public $textReleatedDocumentNumber;
+ public $textRelatedDocumentNumber;
/** @var string */
- public $textReleatedContact;
+ public $textRelatedContact;
/** @var string */
- public $textReleatedDocumentDate;
+ public $textRelatedDocumentDate;
/** @var string */
- public $textReleatedDocumentAmount;
+ public $textRelatedDocumentAmount;
/** @var string */
- public $textReleatedAmount;
+ public $textRelatedAmount;
/** @var string */
public $routeDocumentShow;
@@ -346,8 +346,8 @@ abstract class TransactionShow extends Base
string $textAmount = '', string $textPaidBy = '',
bool $hideContact = false, bool $hideContactInfo = false, bool $hideContactName = false, bool $hideContactAddress = false, bool $hideContactTaxNumber = false,
bool $hideContactPhone = false, bool $hideContactEmail = false,
- bool $hideReletad = false, bool $hideReletadDocumentNumber = false, bool $hideReletadContact = false, bool $hideReletadDocumentDate = false, bool $hideReletadDocumentAmount = false, bool $hideReletadAmount = false,
- string $textReleatedTransansaction = '', string $textReleatedDocumentNumber = '', string $textReleatedContact = '', string $textReleatedDocumentDate = '', string $textReleatedDocumentAmount = '', string $textReleatedAmount = '',
+ bool $hideRelated = false, bool $hideRelatedDocumentNumber = false, bool $hideRelatedContact = false, bool $hideRelatedDocumentDate = false, bool $hideRelatedDocumentAmount = false, bool $hideRelatedAmount = false,
+ string $textRelatedTransansaction = '', string $textRelatedDocumentNumber = '', string $textRelatedContact = '', string $textRelatedDocumentDate = '', string $textRelatedDocumentAmount = '', string $textRelatedAmount = '',
string $routeDocumentShow = '',
bool $hideAttachment = false, $attachment = [],
@@ -464,21 +464,21 @@ abstract class TransactionShow extends Base
$this->hideContactPhone = $hideContactPhone;
$this->hideContactEmail = $hideContactEmail;
- // Releated Information Hide checker
- $this->hideReletad = $hideReletad;
- $this->hideReletadDocumentNumber = $hideReletadDocumentNumber;
- $this->hideReletadContact = $hideReletadContact;
- $this->hideReletadDocumentDate = $hideReletadDocumentDate;
- $this->hideReletadDocumentAmount = $hideReletadDocumentAmount;
- $this->hideReletadAmount = $hideReletadAmount;
+ // Related Information Hide checker
+ $this->hideRelated = $hideRelated;
+ $this->hideRelatedDocumentNumber = $hideRelatedDocumentNumber;
+ $this->hideRelatedContact = $hideRelatedContact;
+ $this->hideRelatedDocumentDate = $hideRelatedDocumentDate;
+ $this->hideRelatedDocumentAmount = $hideRelatedDocumentAmount;
+ $this->hideRelatedAmount = $hideRelatedAmount;
- // Releated Information Text
- $this->textReleatedTransansaction = $this->getTextReleatedTransansaction($type, $textReleatedTransansaction);
- $this->textReleatedDocumentNumber = $this->getTextReleatedDocumentNumber($type, $textReleatedDocumentNumber);
- $this->textReleatedContact = $this->getTextReleatedContact($type, $textReleatedContact);
- $this->textReleatedDocumentDate = $this->getTextReleatedDocumentDate($type, $textReleatedDocumentDate);
- $this->textReleatedDocumentAmount = $this->getTextReleatedDocumentAmount($type, $textReleatedDocumentAmount);
- $this->textReleatedAmount = $this->getTextReleatedAmount($type, $textReleatedAmount);
+ // Related Information Text
+ $this->textRelatedTransansaction = $this->getTextRelatedTransansaction($type, $textRelatedTransansaction);
+ $this->textRelatedDocumentNumber = $this->getTextRelatedDocumentNumber($type, $textRelatedDocumentNumber);
+ $this->textRelatedContact = $this->getTextRelatedContact($type, $textRelatedContact);
+ $this->textRelatedDocumentDate = $this->getTextRelatedDocumentDate($type, $textRelatedDocumentDate);
+ $this->textRelatedDocumentAmount = $this->getTextRelatedDocumentAmount($type, $textRelatedDocumentAmount);
+ $this->textRelatedAmount = $this->getTextRelatedAmount($type, $textRelatedAmount);
$this->routeDocumentShow = $this->routeDocumentShow($type, $routeDocumentShow);
@@ -1093,10 +1093,10 @@ abstract class TransactionShow extends Base
return 'revenues.paid_by';
}
- protected function getTextReleatedTransansaction($type, $textReleatedTransansaction)
+ protected function getTextRelatedTransansaction($type, $textRelatedTransansaction)
{
- if (!empty($textReleatedTransansaction)) {
- return $textReleatedTransansaction;
+ if (!empty($textRelatedTransansaction)) {
+ return $textRelatedTransansaction;
}
switch ($type) {
@@ -1119,10 +1119,10 @@ abstract class TransactionShow extends Base
return 'revenues.related_invoice';
}
- protected function getTextReleatedDocumentNumber($type, $textReleatedDocumentNumber)
+ protected function getTextRelatedDocumentNumber($type, $textRelatedDocumentNumber)
{
- if (!empty($textReleatedDocumentNumber)) {
- return $textReleatedDocumentNumber;
+ if (!empty($textRelatedDocumentNumber)) {
+ return $textRelatedDocumentNumber;
}
$translation = $this->getTextFromConfig($type, 'related_document_number', 'numbers');
@@ -1134,10 +1134,10 @@ abstract class TransactionShow extends Base
return 'general.numbers';
}
- protected function getTextReleatedContact($type, $textReleatedContact)
+ protected function getTextRelatedContact($type, $textRelatedContact)
{
- if (!empty($textReleatedContact)) {
- return $textReleatedContact;
+ if (!empty($textRelatedContact)) {
+ return $textRelatedContact;
}
$default_key = Str::plural(config('type.' . $type . '.contact_type'), 2);
@@ -1151,10 +1151,10 @@ abstract class TransactionShow extends Base
return 'general.customers';
}
- protected function getTextReleatedDocumentDate($type, $textReleatedDocumentDate)
+ protected function getTextRelatedDocumentDate($type, $textRelatedDocumentDate)
{
- if (!empty($textReleatedDocumentDate)) {
- return $textReleatedDocumentDate;
+ if (!empty($textRelatedDocumentDate)) {
+ return $textRelatedDocumentDate;
}
switch ($type) {
@@ -1177,10 +1177,10 @@ abstract class TransactionShow extends Base
return 'invoices.invoice_date';
}
- protected function getTextReleatedDocumentAmount($type, $textReleatedDocumentAmount)
+ protected function getTextRelatedDocumentAmount($type, $textRelatedDocumentAmount)
{
- if (!empty($textReleatedDocumentAmount)) {
- return $textReleatedDocumentAmount;
+ if (!empty($textRelatedDocumentAmount)) {
+ return $textRelatedDocumentAmount;
}
switch ($type) {
@@ -1203,10 +1203,10 @@ abstract class TransactionShow extends Base
return 'general.amount';
}
- protected function getTextReleatedAmount($type, $textReleatedAmount)
+ protected function getTextRelatedAmount($type, $textRelatedAmount)
{
- if (!empty($textReleatedAmount)) {
- return $textReleatedAmount;
+ if (!empty($textRelatedAmount)) {
+ return $textRelatedAmount;
}
$translation = $this->getTextFromConfig($type, 'related_amount', 'amount');
diff --git a/app/Abstracts/View/Components/TransactionTemplate.php b/app/Abstracts/View/Components/TransactionTemplate.php
index 41577dd42..ab7c603b6 100644
--- a/app/Abstracts/View/Components/TransactionTemplate.php
+++ b/app/Abstracts/View/Components/TransactionTemplate.php
@@ -126,40 +126,40 @@ abstract class TransactionTemplate extends Base
public $hideContactEmail;
/** @var bool */
- public $hideReletad;
+ public $hideRelated;
/** @var bool */
- public $hideReletadDocumentNumber;
+ public $hideRelatedDocumentNumber;
/** @var bool */
- public $hideReletadContact;
+ public $hideRelatedContact;
/** @var bool */
- public $hideReletadDocumentDate;
+ public $hideRelatedDocumentDate;
/** @var bool */
- public $hideReletadDocumentAmount;
+ public $hideRelatedDocumentAmount;
/** @var bool */
- public $hideReletadAmount;
+ public $hideRelatedAmount;
/** @var string */
- public $textReleatedTransansaction;
+ public $textRelatedTransansaction;
/** @var string */
- public $textReleatedDocumentNumber;
+ public $textRelatedDocumentNumber;
/** @var string */
- public $textReleatedContact;
+ public $textRelatedContact;
/** @var string */
- public $textReleatedDocumentDate;
+ public $textRelatedDocumentDate;
/** @var string */
- public $textReleatedDocumentAmount;
+ public $textRelatedDocumentAmount;
/** @var string */
- public $textReleatedAmount;
+ public $textRelatedAmount;
/** @var string */
public $routeDocumentShow;
@@ -179,8 +179,8 @@ abstract class TransactionTemplate extends Base
string $textAmount = '', string $textPaidBy = '',
bool $hideContact = false, bool $hideContactInfo = false, bool $hideContactName = false, bool $hideContactAddress = false, bool $hideContactTaxNumber = false,
bool $hideContactPhone = false, bool $hideContactEmail = false,
- bool $hideReletad = false, bool $hideReletadDocumentNumber = false, bool $hideReletadContact = false, bool $hideReletadDocumentDate = false, bool $hideReletadDocumentAmount = false, bool $hideReletadAmount = false,
- string $textReleatedTransansaction = '', string $textReleatedDocumentNumber = '', string $textReleatedContact = '', string $textReleatedDocumentDate = '', string $textReleatedDocumentAmount = '', string $textReleatedAmount = '',
+ bool $hideRelated = false, bool $hideRelatedDocumentNumber = false, bool $hideRelatedContact = false, bool $hideRelatedDocumentDate = false, bool $hideRelatedDocumentAmount = false, bool $hideRelatedAmount = false,
+ string $textRelatedTransansaction = '', string $textRelatedDocumentNumber = '', string $textRelatedContact = '', string $textRelatedDocumentDate = '', string $textRelatedDocumentAmount = '', string $textRelatedAmount = '',
string $routeDocumentShow = ''
) {
$this->type = $type;
@@ -229,21 +229,21 @@ abstract class TransactionTemplate extends Base
$this->hideContactPhone = $hideContactPhone;
$this->hideContactEmail = $hideContactEmail;
- // Releated Information Hide checker
- $this->hideReletad = $hideReletad;
- $this->hideReletadDocumentNumber = $hideReletadDocumentNumber;
- $this->hideReletadContact = $hideReletadContact;
- $this->hideReletadDocumentDate = $hideReletadDocumentDate;
- $this->hideReletadDocumentAmount = $hideReletadDocumentAmount;
- $this->hideReletadAmount = $hideReletadAmount;
+ // Related Information Hide checker
+ $this->hideRelated = $hideRelated;
+ $this->hideRelatedDocumentNumber = $hideRelatedDocumentNumber;
+ $this->hideRelatedContact = $hideRelatedContact;
+ $this->hideRelatedDocumentDate = $hideRelatedDocumentDate;
+ $this->hideRelatedDocumentAmount = $hideRelatedDocumentAmount;
+ $this->hideRelatedAmount = $hideRelatedAmount;
- // Releated Information Text
- $this->textReleatedTransansaction = $this->getTextReleatedTransansaction($type, $textReleatedTransansaction);
- $this->textReleatedDocumentNumber = $this->getTextReleatedDocumentNumber($type, $textReleatedDocumentNumber);
- $this->textReleatedContact = $this->getTextReleatedContact($type, $textReleatedContact);
- $this->textReleatedDocumentDate = $this->getTextReleatedDocumentDate($type, $textReleatedDocumentDate);
- $this->textReleatedDocumentAmount = $this->getTextReleatedDocumentAmount($type, $textReleatedDocumentAmount);
- $this->textReleatedAmount = $this->getTextReleatedAmount($type, $textReleatedAmount);
+ // Related Information Text
+ $this->textRelatedTransansaction = $this->getTextRelatedTransansaction($type, $textRelatedTransansaction);
+ $this->textRelatedDocumentNumber = $this->getTextRelatedDocumentNumber($type, $textRelatedDocumentNumber);
+ $this->textRelatedContact = $this->getTextRelatedContact($type, $textRelatedContact);
+ $this->textRelatedDocumentDate = $this->getTextRelatedDocumentDate($type, $textRelatedDocumentDate);
+ $this->textRelatedDocumentAmount = $this->getTextRelatedDocumentAmount($type, $textRelatedDocumentAmount);
+ $this->textRelatedAmount = $this->getTextRelatedAmount($type, $textRelatedAmount);
$this->routeDocumentShow = $this->routeDocumentShow($type, $routeDocumentShow);
}
@@ -459,10 +459,10 @@ abstract class TransactionTemplate extends Base
return 'revenues.paid_by';
}
- protected function getTextReleatedTransansaction($type, $textReleatedTransansaction)
+ protected function getTextRelatedTransansaction($type, $textRelatedTransansaction)
{
- if (!empty($textReleatedTransansaction)) {
- return $textReleatedTransansaction;
+ if (!empty($textRelatedTransansaction)) {
+ return $textRelatedTransansaction;
}
switch ($type) {
@@ -485,10 +485,10 @@ abstract class TransactionTemplate extends Base
return 'revenues.related_invoice';
}
- protected function getTextReleatedDocumentNumber($type, $textReleatedDocumentNumber)
+ protected function getTextRelatedDocumentNumber($type, $textRelatedDocumentNumber)
{
- if (!empty($textReleatedDocumentNumber)) {
- return $textReleatedDocumentNumber;
+ if (!empty($textRelatedDocumentNumber)) {
+ return $textRelatedDocumentNumber;
}
$translation = $this->getTextFromConfig($type, 'related_document_number', 'numbers');
@@ -500,10 +500,10 @@ abstract class TransactionTemplate extends Base
return 'general.numbers';
}
- protected function getTextReleatedContact($type, $textReleatedContact)
+ protected function getTextRelatedContact($type, $textRelatedContact)
{
- if (!empty($textReleatedContact)) {
- return $textReleatedContact;
+ if (!empty($textRelatedContact)) {
+ return $textRelatedContact;
}
$default_key = Str::plural(config('type.' . $type . '.contact_type'), 2);
@@ -517,10 +517,10 @@ abstract class TransactionTemplate extends Base
return 'general.customers';
}
- protected function getTextReleatedDocumentDate($type, $textReleatedDocumentDate)
+ protected function getTextRelatedDocumentDate($type, $textRelatedDocumentDate)
{
- if (!empty($textReleatedDocumentDate)) {
- return $textReleatedDocumentDate;
+ if (!empty($textRelatedDocumentDate)) {
+ return $textRelatedDocumentDate;
}
switch ($type) {
@@ -543,10 +543,10 @@ abstract class TransactionTemplate extends Base
return 'invoices.invoice_date';
}
- protected function getTextReleatedDocumentAmount($type, $textReleatedDocumentAmount)
+ protected function getTextRelatedDocumentAmount($type, $textRelatedDocumentAmount)
{
- if (!empty($textReleatedDocumentAmount)) {
- return $textReleatedDocumentAmount;
+ if (!empty($textRelatedDocumentAmount)) {
+ return $textRelatedDocumentAmount;
}
switch ($type) {
@@ -569,10 +569,10 @@ abstract class TransactionTemplate extends Base
return 'general.amount';
}
- protected function getTextReleatedAmount($type, $textReleatedAmount)
+ protected function getTextRelatedAmount($type, $textRelatedAmount)
{
- if (!empty($textReleatedAmount)) {
- return $textReleatedAmount;
+ if (!empty($textRelatedAmount)) {
+ return $textRelatedAmount;
}
$translation = $this->getTextFromConfig($type, 'related_amount', 'amount');